This function is used in most plotting routines to check if the correct dataframe is passed.
Examples
if (FALSE) { # \dontrun{
check_df_names(preprocess$biomass_age, expect = c("time", "species", "atoutput", "ages"))
} # }
This function is used in most plotting routines to check if the correct dataframe is passed.
if (FALSE) { # \dontrun{
check_df_names(preprocess$biomass_age, expect = c("time", "species", "atoutput", "ages"))
} # }