Function to convert any column with information about functional groups to a factor whose levels use the LongName of the functional groups file.
Source:R/convert-factor.R
convert_factor.RdThis function is used to match the labels of the plots!
See also
Other convert functions:
convert_bgm(),
convert_time()