R/convert-time.R
convert_time.Rd
Convert timestep to actual time!
convert_time(prm_run, col)
Character string giving the connection of the run parameterfile. The filename usually contains run_fishing and ends in .prm".
run_fishing
.prm
Numeric vector. Usually a column in a dataframe with information about time. Either given as timesteps or days.
Numeric vector with the time in years.
Other convert functions: convert_bgm(), convert_factor()
convert_bgm()
convert_factor()