Skip to contents

Extract conversion factor used to transform data from nitrogen in mg to biomass in tonnes.

Usage

get_conv_mgnbiot(prm_biol)

Arguments

prm_biol

Character string giving the connection to the biological parameterfile. The filename usually contains biol_fishing and does end in .prm.

Value

Conversion factor as numeric value.

See also

Examples

d <- system.file("extdata", "setas-model-new-trunk", package = "atlantistools")
prm_biol <- file.path(d, "VMPA_setas_biol_fishing_Trunk.prm")

get_conv_mgnbiot(prm_biol)
#> [1] 1.14e-07