Extract growth parameters from http:://www.fishbase.se.
Source:R/get-growth-fishbase.R
get_growth_fishbase.RdThis function extracts values for Linf, k and t0 from http:://www.fishbase.se
Details
Before the actual extraction takes place fishbase IDs for every species are extracted using get_ids_fishbase.
The IDs are needed to generate the urls later on.
Examples
if (FALSE) { # \dontrun{
# For some reason the examples break with appveyor.
fish <- c("Gadus morhua", "Merlangius merlangus")
df <- get_growth_fishbase(fish)
head(df)
df <- get_growth_fishbase(fish, mirror = "de")
head(df)
fish <- c("Sprattus sprattus")
df <- get_growth_fishbase(fish)
head(df)
# Only use for debugging purposes.
fish <- read.csv("Z:/my_data_alex/fish_species_names_from_ibts.csv", stringsAsFactors = FALSE)[, 1]
url <- get_growth_fishbase(fish)
url <- urls$ref_url
} # }