Extract fishbase IDs using the package "rfishbase" to generate species specific fishbase URLs
Source:R/get-ids-fishbase.R
get_ids_fishbase.RdThis function extracts fishbase IDs using the database provided by the rfishbase package.
Details
The function depends on the package "rfishbase" which creates a local copy of the fishbase database. The IDs are needed to generate URLs to scan www.fishbase.se for detailed informations about fish growth for example.
Examples
fish <- c("Gadus morhua", "Merlangius merlangus", "Clupea harengus")
get_ids_fishbase(fish)
#> Gadus morhua Merlangius merlangus Clupea harengus
#> 69 29 24