Learn R Programming

atlantistools (version 0.4.1)

get_ref_fishbase: Extract the bibliographic info from www.fishbase.org.

Description

Extract bibliographic information for growth parameters (linf, k, t0) from www.fishbase.org

Usage

get_ref_fishbase(growth_fishbase, mirror = "se")

Arguments

growth_fishbase
Dataframe generated with get_growth_fishbase.
mirror
Character string defining the url mirror to use. Defaults to se. In case data extraction is slow use a different mirror. Try to avoid frequently used mirrors like uk or com.

Value

Dataframe

Examples

Run this code
## Not run: ------------------------------------
# fish <- c("Gadus morhua", "Merlangius merlangus")
# growth_fishbase <- get_growth_fishbase(fish)
# get_ref_fishbase(growth_fishbase)
# 
# growth_fishbase <- get_growth_fishbase("Scyliorhinus canicula")
# df <- get_ref_fishbase(growth_fishbase)
## ---------------------------------------------

Run the code above in your browser using DataLab