Skip to contents

Read in the .bgm file that specifies the the box coordinates for an Atlantis scenario.

Usage

load_box(bgm)

Arguments

bgm

Character string giving the connection to the atlantis bgm file. The filename ends in .bgm.

Value

A list of information regarding boxes for an Atlantis scenario.

Author

Kelli Faye Johnson

Examples

d <- system.file("extdata", "setas-model-new-trunk", package = "atlantistools")
bgm <- file.path(d, "VMPA_setas.bgm")

boxes <- load_box(bgm)