Atlantistools makes heavy use of dplyr data transformations.
Therefore it is advisable to import the pipeoperator %>%
from magrittr.
Atlantistools makes heavy use of dplyr data transformations.
Therefore it is advisable to import the pipeoperator %>%
from magrittr.