Combine values from different groups if specific groups only have a low contribution to the overall value.
Source:R/combine-groups.R
combine_groups.RdCombine values from different groups if specific groups only have a low contribution to the overall value.
Usage
combine_groups(
data,
group_col,
groups = names(data)[!is.element(names(data), c("atoutput", "time", group_col))],
combine_thresh = 15
)See also
Other combine functions:
combine_runs()