Extract conversion factor used to transform data from nitrogen in mg to biomass in tonnes.
Source:R/get-conv-mgnbiot.R
get_conv_mgnbiot.RdExtract conversion factor used to transform data from nitrogen in mg to biomass in tonnes.
See also
Other get functions:
get_boundary(),
get_colpal(),
get_groups()
Examples
d <- system.file("extdata", "setas-model-new-trunk", package = "atlantistools")
prm_biol <- file.path(d, "VMPA_setas_biol_fishing_Trunk.prm")
get_conv_mgnbiot(prm_biol)
#> [1] 1.14e-07